Skip to contents

Summarize a CPB fit

Usage

# S3 method for class 'cpb'
summary(object, ...)

Arguments

object

A "cpb" object.

...

Unused.

Value

An object of class "summary.cpb" with the coefficient table, the dispersion parameter and its profile-likelihood interval (first-order, or calibrated when the fit went through calibrate_alpha()), the implied ceiling, fit statistics, and the likelihood-ratio test against a (zero-truncated) Poisson.