The covariance of the covariate coefficients from the stored pairs/cluster
bootstrap (se = "bootstrap" at fit time); NULL when no bootstrap was run.
Usage
# S3 method for class 'cpb_fe'
vcov(object, ...)The covariance of the covariate coefficients from the stored pairs/cluster
bootstrap (se = "bootstrap" at fit time); NULL when no bootstrap was run.
# S3 method for class 'cpb_fe'
vcov(object, ...)